@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Hash;
 {
-  $List::Objects::WithUtils::Role::Hash::VERSION = '1.010002';
+  $List::Objects::WithUtils::Role::Hash::VERSION = '1.011000';
 }
 use strictures 1;
 
@@ -28,12 +28,14 @@ sub inflated_rw_type { 'List::Objects::WithUtils::Hash::Inflated::RW' }
 
 =pod
 
-=for Pod::Coverage TO_JSON
+=for Pod::Coverage TO_JSON type
 
 =cut
 
 sub TO_JSON { +{ %{ $_[0] } } }
 
+sub type { }
+
 sub new {
   Module::Runtime::require_module( $_[0]->array_type );
   bless +{ @_[1 .. $#_] }, $_[0]
@@ -116,7 +118,6 @@ sub kv {
 
 sub export { %{ $_[0] } }
 
-
 1;
 
 
